@@ -17,14 +17,14 @@
 set -e
 
 log() {
-  echo "`basename $0`: $@"
+    echo "`basename $0`: $@"
 }
 
 usage() {
-  [[ -z "$1" ]] || echo -e "USAGE ERROR: $@\n"
-  echo "`basename $0`: IMAGEFILE DEVICE"
-  echo "  - This script images DEVICE with IMAGEFILE"
-  exit 1
+    [[ -z "$1" ]] || echo -e "USAGE ERROR: $@\n"
+    echo "`basename $0`: IMAGEFILE DEVICE"
+    echo "  - This script images DEVICE with IMAGEFILE"
+    exit 1
 }
 
 IMAGEFILE="$1"
@@ -39,6 +39,9 @@ log "Erasing existing GPT and MBR data structures from ${DEVICE}"
 sgdisk -Z $DEVICE
 
 log "Imaging $IMAGEFILE to $DEVICE"
+
+# limit the memory usage for qemu-img to 1 GiB
+ulimit -v 1048576
 qemu-img convert -t directsync -O host_device $IMAGEFILE $DEVICE
 sync
 
